var __defProp = Object.defineProperty;
var __name = (target, value) => __defProp(target, "name", { value, configurable: true });

// src/shallow-clone-node.ts
var shallowCloneNode = /* @__PURE__ */ __name(function(obj, parent) {
  const cloned = new obj.constructor();
  Object.keys(obj).forEach((i) => {
    if (!obj.hasOwnProperty(i)) {
      return;
    }
    let value = obj[i];
    const type = typeof value;
    if (i === "parent" && type === "object") {
      if (parent) {
        cloned[i] = parent;
      }
    } else if (i === "source") {
      cloned[i] = value;
    } else if (value instanceof Array) {
      if (i === "nodes") {
        cloned[i] = [];
      } else {
        cloned[i] = value.map((j) => shallowCloneNode(j, cloned));
      }
    } else if (i !== "before" && i !== "after" && i !== "between" && i !== "semicolon") {
      if (type === "object") {
        value = shallowCloneNode(value);
      }
      cloned[i] = value;
    }
  });
  return cloned;
}, "shallowCloneNode");

// src/resolve-value.ts
import balanced from "balanced-match";

// src/generate-descendant-pieces-from-selector.ts
var RE_SELECTOR_DESCENDANT_SPLIT = (
  // eslint-disable-next-line no-useless-escape
  /(.*?(?:(?:\([^\)]+\)|\[[^\]]+\]|(?![><+~\s]).)+)(?:(?:(?:\s(?!>>))|(?:\t(?!>>))|(?:\s?>>\s?))(?!\s+))(?![><+~][\s]+?))/
);
var generateDescendantPiecesFromSelector = /* @__PURE__ */ __name(function(selector) {
  return selector.split(RE_SELECTOR_DESCENDANT_SPLIT).filter((piece) => {
    if (piece.length > 0) {
      return true;
    }
    return false;
  }).map(
    (piece) => (
      // Trim whitespace which would be a normal descendant selector
      // and trim off the CSS4 descendant `>>` into a normal descendant selector
      piece.trim().replace(/\s*?>>\s*?/g, "")
    )
  );
}, "generateDescendantPiecesFromSelector");

// src/generate-scope-list.ts
var generateScopeList = /* @__PURE__ */ __name(function(node, includeSelf) {
  includeSelf = includeSelf || false;
  let selectorScopeList = [
    // Start off with one branch
    []
  ];
  let currentNodeParent = includeSelf ? node : node.parent;
  while (currentNodeParent) {
    let scopePieces = (currentNodeParent.selectors || []).map((selectorPiece) => {
      return {
        type: "selector",
        value: selectorPiece
      };
    });
    if (currentNodeParent.type === "atrule") {
      scopePieces = [].concat(currentNodeParent.params).map((param) => {
        return {
          type: "atrule",
          value: `@${currentNodeParent.name} ${param}`
        };
      });
    }
    const branches = (scopePieces.length > 0 ? scopePieces : [1]).map(
      () => selectorScopeList.map((scopePieces2) => scopePieces2.slice(0))
    );
    scopePieces.forEach((scopeObject, index) => {
      branches[index] = branches[index].map((scopeStringPieces) => {
        let descendantPieces = [scopeObject.value];
        if (scopeObject.type === "selector") {
          descendantPieces = generateDescendantPiecesFromSelector(scopeObject.value);
        }
        scopeStringPieces.unshift.apply(scopeStringPieces, descendantPieces);
        return scopeStringPieces;
      });
    });
    selectorScopeList = [];
    branches.forEach((branch) => {
      selectorScopeList = selectorScopeList.concat(branch);
    });
    currentNodeParent = currentNodeParent.parent;
  }
  return selectorScopeList;
}, "generateScopeList");

// src/is-under-scope.ts
import escapeStringRegexp from "escape-string-regexp";

// src/is-piece-always-ancestor-selector.ts
var alwaysAncestorSelector = {
  "*": true,
  ":root": true,
  html: true
};
var isPieceAlwaysAncestorSelector = /* @__PURE__ */ __name(function(piece) {
  return !!alwaysAncestorSelector[piece];
}, "isPieceAlwaysAncestorSelector");

// src/generate-direct-descendant-pieces-from-selector.ts
var RE_SELECTOR_DIRECT_DESCENDANT_SPLIT = (
  // eslint-disable-next-line no-useless-escape
  /(.*?(?:(?:\([^\)]+\)|\[[^\]]+\]|(?!>>|<|\+|~|\s).)+)(?:(?:(?:>(?!>))|(?:\s?>(?!>)\s?))(?!\s+))(?!(?:>>|<|\+|~)[\s]+?))/
);
var generateDirectDescendantPiecesFromSelector = /* @__PURE__ */ __name(function(selector) {
  return selector.split(RE_SELECTOR_DIRECT_DESCENDANT_SPLIT).filter((piece) => {
    if (piece.length > 0) {
      return true;
    }
    return false;
  }).map(
    (piece) => (
      // Trim whitespace which would be a normal descendant selector
      // and trim off the CSS4 descendant `>>` into a normal descendant selector
      piece.trim().replace(/\s*?>\s*?/g, "")
    )
  );
}, "generateDirectDescendantPiecesFromSelector");

// src/is-under-scope.ts
var RE_AT_RULE_SCOPE_PIECE = /^@.*/;
var RE_PSEUDO_SELECTOR = /([^\s:]+)(?<!\\)((?::|::)[^\s]*?)(\s+|$)/;
function getScopeMatchResults(nodeScopeList, scopeNodeScopeList) {
  let currentPieceOffset;
  let scopePieceIndex;
  const doesMatchScope = scopeNodeScopeList.some(
    (scopeNodeScopePieces) => nodeScopeList.some((nodeScopePieces) => {
      currentPieceOffset = null;
      let wasEveryPieceFound = true;
      for (scopePieceIndex = 0; scopePieceIndex < scopeNodeScopePieces.length; scopePieceIndex++) {
        const scopePiece = scopeNodeScopePieces[scopePieceIndex];
        const pieceOffset = currentPieceOffset || 0;
        let foundIndex = -1;
        const piecesWeCanMatch = nodeScopePieces.slice(pieceOffset);
        for (let nodeScopePieceIndex = 0; nodeScopePieceIndex < piecesWeCanMatch.length; nodeScopePieceIndex++) {
          const nodeScopePiece = piecesWeCanMatch[nodeScopePieceIndex];
          const overallIndex = pieceOffset + nodeScopePieceIndex;
          if (
            // If the part on the end of the piece itself matches:
            //		scopePiece `.bar` matches node `.bar`
            //		scopePiece `.bar` matches node `.foo + .bar`
            new RegExp(`${escapeStringRegexp(scopePiece)}$`).test(nodeScopePiece)
          ) {
            foundIndex = overallIndex;
            break;
          }
          if (isPieceAlwaysAncestorSelector(scopePiece) || isPieceAlwaysAncestorSelector(nodeScopePiece)) {
            foundIndex = overallIndex;
            break;
          }
          const directDescendantPieces = generateDirectDescendantPiecesFromSelector(nodeScopePiece);
          if (directDescendantPieces.length > 1) {
            const ddNodeScopeList = [].concat([directDescendantPieces]);
            const ddScopeList = [].concat([
              scopeNodeScopePieces.slice(scopePieceIndex).reduce(
                (prevScopePieces, scopePiece2) => prevScopePieces.concat(generateDirectDescendantPiecesFromSelector(scopePiece2)),
                []
              )
            ]);
            const result = getScopeMatchResults(ddNodeScopeList, ddScopeList);
            if (result.doesMatchScope || scopePieceIndex + 1 < scopeNodeScopePieces.length) {
              foundIndex = overallIndex;
              scopePieceIndex += result.scopePieceIndex - 1;
            }
            break;
          }
        }
        const isFurther = foundIndex >= pieceOffset;
        currentPieceOffset = foundIndex + 1;
        wasEveryPieceFound = wasEveryPieceFound && isFurther;
        if (!wasEveryPieceFound) {
          break;
        }
      }
      return wasEveryPieceFound;
    })
  );
  return {
    doesMatchScope,
    nodeScopePieceIndex: currentPieceOffset ? currentPieceOffset - 1 : 0,
    scopePieceIndex
  };
}
__name(getScopeMatchResults, "getScopeMatchResults");
var stripPseudoSelectorsFromScopeList = /* @__PURE__ */ __name(function(scopeList) {
  return scopeList.map(
    (scopePieces) => scopePieces.map((descendantPiece) => {
      if (!RE_AT_RULE_SCOPE_PIECE.test(descendantPiece)) {
        return descendantPiece.replace(
          new RegExp(RE_PSEUDO_SELECTOR.source, "g"),
          (_whole, baseSelector, _pseudo, trailingWhitespace) => baseSelector + trailingWhitespace
        );
      }
      return descendantPiece;
    })
  );
}, "stripPseudoSelectorsFromScopeList");
var isUnderScope = /* @__PURE__ */ __name(function(nodeScopeList, scopeNodeScopeList, ignorePseudo) {
  nodeScopeList = stripPseudoSelectorsFromScopeList(nodeScopeList);
  if (ignorePseudo) {
    scopeNodeScopeList = stripPseudoSelectorsFromScopeList(scopeNodeScopeList);
  }
  return getScopeMatchResults(nodeScopeList, scopeNodeScopeList).doesMatchScope;
}, "isUnderScope");
isUnderScope.RE_PSEUDO_SELECTOR = RE_PSEUDO_SELECTOR;

// src/is-node-under-scope.ts
var isNodeUnderScope = /* @__PURE__ */ __name(function(node, scopeNode, ignorePseudo) {
  const nodeScopeList = generateScopeList(node, true);
  const scopeNodeScopeList = generateScopeList(scopeNode, true);
  return isUnderScope(nodeScopeList, scopeNodeScopeList, ignorePseudo);
}, "isNodeUnderScope");

// src/gather-variable-dependencies.ts
var gatherVariableDependencies = /* @__PURE__ */ __name(function(variablesUsed, map, _dependencyVariablesList) {
  _dependencyVariablesList = _dependencyVariablesList || [];
  let hasCircularOrSelfReference = false;
  if (variablesUsed) {
    _dependencyVariablesList = variablesUsed.reduce(
      (dependencyVariablesList, variableUsedName) => {
        const isVariableInMap = !!map[variableUsedName];
        const doesThisVarHaveCircularOrSelfReference = !isVariableInMap ? false : dependencyVariablesList.some(
          (dep) => map[variableUsedName].some((mapItem) => {
            if (dep === mapItem) {
              return true;
            }
            return false;
          })
        );
        hasCircularOrSelfReference = hasCircularOrSelfReference || doesThisVarHaveCircularOrSelfReference;
        if (isVariableInMap && !hasCircularOrSelfReference) {
          dependencyVariablesList = dependencyVariablesList.concat(map[variableUsedName]);
          (map[variableUsedName] || []).forEach((mapItem) => {
            const result = gatherVariableDependencies(
              mapItem.variablesUsed,
              map,
              dependencyVariablesList
            );
            dependencyVariablesList = result.deps;
            hasCircularOrSelfReference = hasCircularOrSelfReference || result.hasCircularOrSelfReference;
          });
        }
        return dependencyVariablesList;
      },
      _dependencyVariablesList
    );
  }
  return {
    deps: _dependencyVariablesList,
    hasCircularOrSelfReference
  };
}, "gatherVariableDependencies");

// src/find-node-ancestor-with-selector.ts
var findNodeAncestorWithSelector = /* @__PURE__ */ __name(function(selector, node) {
  let matchingNode;
  let currentNode = node;
  while (currentNode.parent && !matchingNode) {
    const currentNodeScopeList = generateScopeList(currentNode.clone(), true);
    currentNodeScopeList.some(
      (scopePieces) => scopePieces.some((scopePiece) => {
        if (scopePiece === selector) {
          matchingNode = currentNode;
          return true;
        }
        return false;
      })
    );
    currentNode = currentNode.parent;
  }
  return matchingNode;
}, "findNodeAncestorWithSelector");

// src/clone-splice-parent-onto-node-when.ts
var cloneSpliceParentOntoNodeWhen = /* @__PURE__ */ __name(function(node, parent, whenCb) {
  whenCb = whenCb || function() {
    return true;
  };
  const cloneList = [];
  let current = node;
  let isWhenNow = false;
  while (current && !isWhenNow) {
    if (current.type === "decl") {
      cloneList.push(current.clone());
    } else {
      cloneList.push(shallowCloneNode(current));
    }
    isWhenNow = whenCb(current);
    current = current.parent;
  }
  const cloneParentList = [];
  let currentParent = parent;
  while (currentParent) {
    cloneParentList.push(shallowCloneNode(currentParent));
    currentParent = currentParent.parent;
  }
  cloneParentList.forEach((parentClone, index, cloneParentList2) => {
    if (index + 1 < cloneParentList2.length) {
      parentClone.parent = cloneParentList2[index + 1];
    }
  });
  cloneList.forEach((clone, index, cloneList2) => {
    if (index + 1 < cloneList2.length) {
      clone.parent = cloneList2[index + 1];
    } else {
      cloneParentList.slice(-1)[0].parent = current;
      clone.parent = cloneParentList[0];
    }
  });
  return cloneList[0];
}, "cloneSpliceParentOntoNodeWhen");

// src/resolve-value.ts
var RE_VAR_FUNC = /var\(\s*(--[^,\s)]+)/;
function toString(value) {
  return String(value);
}
__name(toString, "toString");
function balancedVar(value) {
  const match = balanced("(", ")", value);
  if (match) {
    if (/(?:^|[^\w-])var$/.test(match.pre)) {
      return {
        body: match.body,
        post: match.post,
        pre: match.pre.slice(0, -3)
      };
    }
    const bodyMatch = balancedVar(match.body);
    if (bodyMatch) {
      return {
        body: bodyMatch.body,
        post: `${bodyMatch.post})${match.post}`,
        pre: `${match.pre}(${bodyMatch.pre}`
      };
    }
    const postMatch = balancedVar(match.post);
    if (postMatch) {
      return {
        body: postMatch.body,
        post: postMatch.post,
        pre: `${match.pre}(${match.body})${postMatch.pre}`
      };
    }
  }
}
__name(balancedVar, "balancedVar");
var resolveValue = /* @__PURE__ */ __name(function(decl, map, ignorePseudoScope, _debugIsInternal) {
  let matchingVarDecl;
  let resultantValue = toString(decl.value);
  const warnings = [];
  const variablesUsedInValueMap = {};
  let remainingVariableValue = resultantValue;
  while (matchingVarDecl = balancedVar(remainingVariableValue)) {
    const variableFallbackSplitPieces = matchingVarDecl.body.split(",");
    const variableName = variableFallbackSplitPieces[0].trim();
    variablesUsedInValueMap[variableName] = true;
    remainingVariableValue = (matchingVarDecl.pre || "") + matchingVarDecl.body.replace(variableName, "") + (matchingVarDecl.post || "");
  }
  remainingVariableValue = void 0;
  const variablesUsedInValue = Object.keys(variablesUsedInValueMap);
  let isResultantValueUndefined = false;
  while (matchingVarDecl = balancedVar(resultantValue)) {
    let matchingVarDeclMapItem;
    const variableFallbackSplitPieces = matchingVarDecl.body.split(",");
    const variableName = variableFallbackSplitPieces[0].trim();
    const fallback = variableFallbackSplitPieces.length > 1 ? variableFallbackSplitPieces.slice(1).join(",").trim() : void 0;
    (map[variableName] || []).forEach((varDeclMapItem) => {
      const underScsopeIgnorePseudo = isNodeUnderScope(
        decl.parent,
        varDeclMapItem.parent,
        ignorePseudoScope
      );
      if (underScsopeIgnorePseudo && // And if the currently matched declaration is `!important`, it will take another `!important` to override it
      (!(matchingVarDeclMapItem || {}).isImportant || varDeclMapItem.isImportant)) {
        matchingVarDeclMapItem = varDeclMapItem;
      }
    });
    let replaceValue = (matchingVarDeclMapItem || {}).calculatedInPlaceValue || function() {
      let fallbackValue = fallback;
      if (fallback) {
        const fallbackDecl = decl.clone({ parent: decl.parent, value: fallback });
        fallbackValue = resolveValue(
          fallbackDecl,
          map,
          false,
          /* internal*/
          true
        ).value;
      }
      return fallbackValue;
    }();
    if (matchingVarDeclMapItem !== void 0 && !gatherVariableDependencies(variablesUsedInValue, map).hasCircularOrSelfReference) {
      const varDeclScopeList = generateScopeList(decl.parent.parent, true);
      const innerMostAtRuleSelector = varDeclScopeList[0].slice(-1)[0];
      const nodeToSpliceParentOnto = findNodeAncestorWithSelector(
        innerMostAtRuleSelector,
        matchingVarDeclMapItem.decl.parent
      );
      const matchingMimicDecl = cloneSpliceParentOntoNodeWhen(
        matchingVarDeclMapItem.decl,
        decl.parent.parent,
        (ancestor) => ancestor === nodeToSpliceParentOnto
      );
      replaceValue = resolveValue(
        matchingMimicDecl,
        map,
        false,
        /* internal*/
        true
      ).value;
    }
    isResultantValueUndefined = replaceValue === void 0;
    if (isResultantValueUndefined) {
      warnings.push([
        `variable ${variableName} is undefined and used without a fallback`,
        { node: decl }
      ]);
    }
    resultantValue = (matchingVarDecl.pre || "") + replaceValue + (matchingVarDecl.post || "");
  }
  return {
    // The resolved value
    value: !isResultantValueUndefined ? resultantValue : void 0,
    // Array of variable names used in resolving this value
    variablesUsed: variablesUsedInValue,
    // Any warnings generated from parsing this value
    warnings
  };
}, "resolveValue");
resolveValue.RE_VAR_FUNC = RE_VAR_FUNC;

// src/resolve-decl.ts
function eachMapItemDependencyOfDecl(variablesUsedList, map, decl, cb) {
  variablesUsedList.forEach((_variableUsedName) => {
    gatherVariableDependencies(variablesUsedList, map).deps.forEach((mapItem) => {
      let mimicDecl;
      if (mapItem.isUnderAtRule) {
        const varDeclScopeList = generateScopeList(mapItem.parent, true);
        const innerMostAtRuleSelector = varDeclScopeList[0].slice(-1)[0];
        const nodeToSpliceParentOnto = findNodeAncestorWithSelector(
          innerMostAtRuleSelector,
          decl.parent
        );
        const varDeclAtRule = mapItem.parent.parent;
        mimicDecl = cloneSpliceParentOntoNodeWhen(
          decl,
          varDeclAtRule,
          (ancestor) => ancestor === nodeToSpliceParentOnto
        );
      } else if (isUnderScope.RE_PSEUDO_SELECTOR.test(mapItem.parent.selector)) {
        const ruleClone = shallowCloneNode(decl.parent);
        ruleClone.parent = decl.parent.parent;
        mimicDecl = decl.clone();
        ruleClone.append(mimicDecl);
        const lastPseudoSelectorMatches = mapItem.parent.selector.match(
          new RegExp(`${isUnderScope.RE_PSEUDO_SELECTOR.source}$`)
        );
        const lastPseudoSelector = lastPseudoSelectorMatches ? lastPseudoSelectorMatches[2] : "";
        ruleClone.selector += lastPseudoSelector;
      }
      if (mimicDecl && isNodeUnderScope(mimicDecl, mapItem.parent, true)) {
        cb(mimicDecl, mapItem);
      }
    });
  });
}
__name(eachMapItemDependencyOfDecl, "eachMapItemDependencyOfDecl");
var resolveDecl = /* @__PURE__ */ __name(function(decl, map, shouldPreserve, preserveAtRulesOrder, logResolveValueResult) {
  shouldPreserve = (typeof shouldPreserve === "function" ? shouldPreserve(decl) : shouldPreserve) || false;
  preserveAtRulesOrder = preserveAtRulesOrder || false;
  const _logResolveValueResult = /* @__PURE__ */ __name(function(valueResults2) {
    if (logResolveValueResult) {
      logResolveValueResult(valueResults2);
    }
    return valueResults2;
  }, "_logResolveValueResult");
  const valueResults = _logResolveValueResult(resolveValue(decl, map));
  let previousAtRuleNode;
  eachMapItemDependencyOfDecl(
    valueResults.variablesUsed,
    map,
    decl,
    (mimicDecl, mapItem) => {
      const ruleClone = shallowCloneNode(decl.parent);
      const declClone = decl.clone();
      ruleClone.append(declClone);
      let preserveVariable;
      if (typeof shouldPreserve === "function") {
        preserveVariable = shouldPreserve(decl);
      } else {
        preserveVariable = shouldPreserve;
      }
      if (preserveVariable === true) {
        declClone.cloneAfter();
      }
      declClone.value = _logResolveValueResult(resolveValue(mimicDecl, map, true)).value;
      if (mapItem.isUnderAtRule) {
        const atRuleNode = shallowCloneNode(mapItem.parent.parent);
        atRuleNode.append(ruleClone);
        let parentAtRuleNode = atRuleNode;
        let currentAtRuleNode = mapItem.parent.parent;
        while (currentAtRuleNode.parent.type === "atrule") {
          const newParentAtRuleNode = shallowCloneNode(currentAtRuleNode.parent);
          newParentAtRuleNode.append(parentAtRuleNode);
          parentAtRuleNode = newParentAtRuleNode;
          currentAtRuleNode = currentAtRuleNode.parent;
        }
        decl.parent.parent.insertAfter(
          preserveAtRulesOrder && previousAtRuleNode || decl.parent,
          parentAtRuleNode
        );
        previousAtRuleNode = parentAtRuleNode;
      } else {
        ruleClone.selector = mimicDecl.parent.selector;
        decl.parent.parent.insertAfter(
          preserveAtRulesOrder && previousAtRuleNode || decl.parent,
          ruleClone
        );
      }
    }
  );
  if (shouldPreserve === true && decl.value !== valueResults.value) {
    decl.cloneAfter();
  }
  if (valueResults.value === void 0) {
    valueResults.value = "undefined";
  }
  decl.value = valueResults.value;
}, "resolveDecl");

// src/index.ts
var RE_VAR_PROP = /(--(.+))/;
function eachCssVariableDeclaration(css, cb) {
  css.walkDecls((decl) => {
    if (RE_VAR_PROP.test(decl.prop)) {
      cb(decl);
    }
  });
}
__name(eachCssVariableDeclaration, "eachCssVariableDeclaration");
function cleanUpNode(node) {
  let nodeToPossiblyCleanUp = node;
  while (nodeToPossiblyCleanUp && nodeToPossiblyCleanUp.nodes.length <= 0) {
    const nodeToRemove = nodeToPossiblyCleanUp.type !== "root" ? nodeToPossiblyCleanUp : null;
    if (nodeToRemove) {
      nodeToPossiblyCleanUp = nodeToRemove.parent;
      nodeToRemove.remove();
    } else {
      nodeToPossiblyCleanUp = null;
    }
  }
}
__name(cleanUpNode, "cleanUpNode");
var defaults = {
  // Allows you to preserve custom properties & var() usage in output.
  // `true`, `false`, or `'computed'`
  preserve: false,
  // Will write media queries in the same order as in the original file.
  // Currently defaulted to false for legacy behavior. We can update to `true` in a major version
  preserveAtRulesOrder: false,
  // Preserve variables injected via JS with the `variables` option above
  // before serializing to CSS (`false` will remove these variables from output)
  preserveInjectedVariables: true,
  // Define variables via JS
  // Simple key-value pair
  // or an object with a `value` property and an optional `isImportant` bool property
  variables: {}
};
var postcssVarReplace = /* @__PURE__ */ __name((options = {}) => {
  const opts = Object.assign({}, defaults, options);
  return {
    Once(css, { decl, result, rule }) {
      const nodesToRemoveAtEnd = [];
      const injectedDeclsToRemoveAtEnd = [];
      let map = {};
      map = Object.assign(
        map,
        Object.keys(opts.variables).reduce((prevVariableMap, variableName) => {
          const variableEntry = opts.variables[variableName];
          variableName = variableName.slice(0, 2) === "--" ? variableName : `--${variableName}`;
          const variableValue = (variableEntry || {}).value || variableEntry;
          const isImportant = (variableEntry || {}).isImportant || false;
          const variableRootRule = rule({ selector: ":root" });
          css.root().prepend(variableRootRule);
          const varDecl = decl({
            important: isImportant,
            prop: variableName,
            value: variableValue
          });
          variableRootRule.append(varDecl);
          if (!opts.preserveInjectedVariables) {
            injectedDeclsToRemoveAtEnd.push(varDecl);
          }
          prevVariableMap[variableName] = (prevVariableMap[variableName] || []).concat({
            calculatedInPlaceValue: variableValue,
            decl: varDecl,
            isImportant,
            isUnderAtRule: false,
            parent: variableRootRule,
            prop: variableName,
            variablesUsed: []
          });
          return prevVariableMap;
        }, {})
      );
      const logResolveValueResult = /* @__PURE__ */ __name(function(valueResult) {
        const warningList = [].concat(valueResult.warnings);
        warningList.forEach((warningArgs) => {
          warningArgs = [].concat(warningArgs);
          result.warn.apply(result, warningArgs);
        });
        return valueResult;
      }, "logResolveValueResult");
      eachCssVariableDeclaration(css, (decl2) => {
        const declParentRule = decl2.parent;
        const valueResults = logResolveValueResult(resolveValue(decl2, map));
        decl2.parent.selectors.forEach((selector) => {
          const splitOutRule = shallowCloneNode(decl2.parent);
          splitOutRule.selector = selector;
          splitOutRule.parent = decl2.parent.parent;
          const declClone = decl2.clone();
          splitOutRule.append(declClone);
          const { prop } = decl2;
          map[prop] = (map[prop] || []).concat({
            calculatedInPlaceValue: valueResults.value,
            decl: declClone,
            isImportant: decl2.important || false,
            // variables inside root or at-rules (eg. @media, @support)
            isUnderAtRule: splitOutRule.parent.type === "atrule",
            parent: splitOutRule,
            prop,
            variablesUsed: valueResults.variablesUsed
          });
        });
        let preserveDecl;
        if (typeof opts.preserve === "function") {
          preserveDecl = opts.preserve(decl2);
        } else {
          preserveDecl = opts.preserve;
        }
        if (!preserveDecl) {
          decl2.remove();
        } else if (preserveDecl === "computed") {
          decl2.value = valueResults.value;
        }
        if (declParentRule.nodes.length <= 0) {
          nodesToRemoveAtEnd.push(declParentRule);
        }
      });
      const rulesThatHaveDeclarationsWithVariablesList = [];
      css.walk((rule2) => {
        if (rule2.nodes === void 0)
          return;
        const doesRuleUseVariables = rule2.nodes.some((node) => {
          if (node.type === "decl") {
            const decl2 = node;
            if (resolveValue.RE_VAR_FUNC.test(decl2.value) && !RE_VAR_PROP.test(decl2.prop)) {
              return true;
            }
          }
          return false;
        });
        if (doesRuleUseVariables) {
          if (rule2.type === "rule" && rule2.selectors.length > 1) {
            rule2.selectors.reverse().forEach((selector) => {
              const ruleClone = rule2.cloneAfter();
              ruleClone.selector = selector;
              return ruleClone;
            });
            rule2.remove();
          } else {
            rulesThatHaveDeclarationsWithVariablesList.push(rule2);
          }
        }
      });
      rulesThatHaveDeclarationsWithVariablesList.forEach((rule2) => {
        rule2.nodes.slice(0).forEach((node) => {
          if (node.type === "decl") {
            const decl2 = node;
            resolveDecl(decl2, map, opts.preserve, opts.preserveAtRulesOrder, logResolveValueResult);
          }
        });
      });
      nodesToRemoveAtEnd.forEach(cleanUpNode);
      injectedDeclsToRemoveAtEnd.forEach((injectedDecl) => {
        injectedDecl.remove();
      });
    },
    postcssPlugin: "postcss-var-replace"
  };
}, "postcssVarReplace");
postcssVarReplace.postcss = true;
export {
  postcssVarReplace
};
//# sourceMappingURL=index.mjs.map